@@ -22,9 +22,9 @@ from fiber.init import init_fiber
 from fiber.meta import meta
 
 
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 
-logger = logging.getLogger('fiber')
+logger = logging.getLogger('Trax')
 
 
 if sys.platform == 'win32':
