@@ -70,7 +70,7 @@ import configparser
 
 
 _current_config = None
-logger = logging.getLogger('fiber')
+logger = logging.getLogger('Trax')
 
 
 LOG_LEVELS = {
