@@ -35,7 +35,7 @@ import fiber.queues
 from fiber import process
 from fiber.backend import get_backend
 
-logger = logging.getLogger('fiber')
+logger = logging.getLogger('Trax')
 
 
 default_family = 'AF_INET'
