@@ -62,7 +62,7 @@ if fiber.util.is_in_interactive_console():
 else:
     import pickle
 
-logger = logging.getLogger('fiber')
+logger = logging.getLogger('Trax')
 
 MIN_PORT = 40000
 MAX_PORT = 65535
